@@ -33,6 +33,10 @@ class Index:
         """Support str()."""
         return "(" + ", ".join(map(str, self.names)) + ")"
 
+    def __sentry_repr__(self):
+        """Support Sentry."""
+        return str(self)
+
     @property
     def nlevels(self) -> int:
         """Return the number of index levels."""
@@ -80,10 +84,6 @@ class Index:
                 return False
         return True
 
-    def __sentry_repr__(self):
-        """Support Sentry."""
-        return str(self)
-
     @property
     def name(self) -> Hashable:
         """
@@ -140,6 +140,27 @@ class Index:
             return np.array([], dtype=int)
         return self._parent.duplicated(self._parent._index, keep)
 
+    def diff(self, other: "Index") -> npt.NDArray[np.int_]:
+        """
+        Calculate positions of the unique index values that are not present in the other index.
+
+        :param other: Index with values which should be excluded.
+        :return: Positions of unique values in the index not present in the other index.
+        """
+        if not isinstance(other, Index):
+            raise TypeError(f"other must be a medvedi.Index, got {type(other)}")
+        columns = self._parent._columns
+        order_self, merged_self = DataFrame._order([columns[i] for i in self._parent._index])
+        columns = other._parent._columns
+        order_other, merged_other = DataFrame._order([columns[i] for i in other._parent._index])
+        _, first_found = np.unique(
+            np.concatenate([merged_other[order_other], merged_self[order_self]]),
+            return_index=True,
+        )
+        return np.sort(
+            order_self[first_found[first_found >= len(merged_other)] - len(merged_other)],
+        )
+
 
 @dataclass(frozen=True, slots=True)
 class Grouper:
@@ -1042,8 +1063,8 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
                 for i, c in enumerate(index):
                     transposed_resolved_indexes_builder[i].append(df[c])
         transposed_resolved_indexes: list[np.ndarray] = [
-            np.concatenate(vals, casting="unsafe") if vals else []
-            for vals in transposed_resolved_indexes_builder
+            np.concatenate(vals, casting="unsafe") if vals else dfs[0]._columns[c]
+            for vals, c in zip(transposed_resolved_indexes_builder, indexes[0])
         ]
         del transposed_resolved_indexes_builder
         if len(transposed_resolved_indexes) == 1:
